@file:OptIn(ExperimentalMaterial3Api::class)

package com.example.app.screens

import android.content.Context
import android.widget.Toast
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import com.arcgismaps.mapping.ArcGISMap
import com.arcgismaps.mapping.BasemapStyle
import com.arcgismaps.mapping.MobileMapPackage
import com.arcgismaps.toolkit.geoviewcompose.MapView
import com.example.app.R
import java.io.File

@Composable
fun MainScreen() {

    val context = LocalContext.current
    // Get the path of the mobile map package
    val mmpkFilePath = context.getExternalFilesDir(null)?.path + File.separator + stringResource(id = R.string.mahourivieratrails_mmpk)
    // Create the ArcGIS Map which would use the map provided by the map package

    val map = remember {

        mutableStateOf(ArcGISMap(BasemapStyle.ArcGISTopographic))

    }

    LaunchedEffect(Unit) {

        // Load the mobile map package
        val mapPackage = MobileMapPackage(mmpkFilePath)

        mapPackage.load().onSuccess {
            map.value = mapPackage.maps.first()
        }.onFailure { error ->
            showError(context, "Failed to load mobile map package: ${error.message}")
        }

    }

    Scaffold(
        topBar = { TopAppBar(title = { Text(text = stringResource(id = R.string.app_name)) }) }
    ) {
        // Display map when the mobile map package is loaded
        MapView(
            modifier = Modifier.fillMaxSize().padding(it),

            arcGISMap = map.value

        )
    }
}

fun showError(context: Context, message: String) {
    Toast.makeText(context, message, Toast.LENGTH_LONG).show()
}

